import { FormInstance } from 'antd';
import { DataSource } from "../FormulaView";
import { FormulaData } from "../FormulaView/type";
import { FC } from 'react';
interface FormulaValue {
    dataName: string;
    calculation: [string, FormulaData[]];
    unit: string;
}
interface Props {
    /**
     * @description 页面样式类名
     * @type string
     */
    pageClassName?: string;
    /**
     * @description 数据菜单样式类名
     * @type string
     */
    dataMenuClassName?: string;
    /**
     * @description form表单实例
     * @type FormInstance<any>
     */
    form?: FormInstance<any>;
    /**
     * @description 数据源
     * @type DataSource[]
     * @default []
     */
    dataSource: DataSource[];
    /**
     * @description 数据源映射对象
     * @type Record<string, string>
     */
    mapData?: Record<string, string>;
    /**
     * @description 计算详情值
     * @type FormulaValue
     */
    formulaValue?: FormulaValue;
    /**
     * @description 生成ID映射标签方法
     * @type (e: (str: string) => void) => void
     */
    commitCallback: (e: (str: string) => void) => void;
    /**
     * @description 点击数据菜单项事件
     * @type (current: DataSource, items: DataSource[]) => void
     */
    onDataMenuItemClick?: (current: DataSource, items: DataSource[]) => void;
    /**
     * @description 点击删除事件
     * @type () => void
     */
    onDeleteBtn?: () => void;
    /**
     * @description 点击取消事件
     * @type () => void
     */
    onCancelBtn?: () => void;
    /**
     * @description 点击保存事件
     * @type (data: any) => void
     */
    onSubmitBtn: (data: any) => void;
    /**
     * @description 代码视图标签点击事件
     * @type (params: {
      sourceList: DataSource[];
      onChange: (
        secondInfo?: string,
        otherInfo?: string,
      ) => void; sourceList: 第一个代表父级，第二个代表子级...
     */
    onPlaceholderClick?: (params: {
        secondInfo: string;
        otherInfo: string;
        sourceList: DataSource[];
        onChange: (secondInfo?: string, otherInfo?: string) => void;
    }) => void;
}
declare const FormulaPage: FC<Props>;
export default FormulaPage;
export type { Props as FormulaPageProps, FormulaValue };
