import React from 'react';
import { FormulaData } from './type';
interface DataSource {
    id: number | string;
    label: string;
    code?: string;
    children?: Array<DataSource & {
        parentId?: number;
    }>;
}
interface Props {
    /**
     * @description 数据源
     * @type DataSource[]
     */
    dataSource: DataSource[];
    /**
     * @description 数据源映射对象
     * @type Record<string, string>
     */
    mapData?: Record<string, string>;
    /**
     * @description 输入值
     * @type [string, FormulaData[]]
     */
    value?: [string, FormulaData[]];
    /**
     * @description 公式计算输入值变更
     * @type (value: [string, FormulaData[]]) => void
     */
    onChange?: (value: [string, FormulaData[]]) => void;
    /**
     * @description 公式计算回调-用于外部调用
     * @type (insertStr: (str: string) => void) => void
     */
    callback: (insertStr: (str: string) => void) => void;
    /**
     * @description 公式计算标签点击事件
     * @type (params: {
      sourceList: DataSource[];
      onChange: (
        secondInfo?: string,
        otherInfo?: string,
      ) => void; sourceList: 第一个代表父级，第二个代表子级...
     */
    onPlaceholderClick?: (params: {
        secondInfo: string;
        otherInfo: string;
        sourceList: DataSource[];
        onChange: (secondInfo?: string, otherInfo?: string) => void;
    }) => void;
}
declare function FormulaView(props: Props): React.JSX.Element;
export default FormulaView;
export type { DataSource, FormulaData, Props as FormulaViewProps };
